@@ -180,7 +180,7 @@ class RDSClient():
                                status: str) -> bool:
         """
         """
-        query = f'UPDATEneuralplatform_page SET imgStatus = "{status}" WHERE id = {page_id};'
+        query = f'UPDATE neuralplatform_page SET imgStatus = "{status}" WHERE id = {page_id};'
         return self.insert_query(query)
     
     def update_page_ocr_status(self,
@@ -188,7 +188,7 @@ class RDSClient():
                                status: str) -> bool:
         """
         """
-        query = f'UPDATEneuralplatform_page SET ocrStatus = "{status}" WHERE id = {page_id};'
+        query = f'UPDATE neuralplatform_page SET ocrStatus = "{status}" WHERE id = {page_id};'
         return self.insert_query(query)
 
     def get_page(self,
@@ -198,6 +198,13 @@ class RDSClient():
         query = f"SELECT * FROM neuralplatform_page WHERE id = {page_id};"
         return self.select_query(query, fetchone=True)
     
+    def get_pages(self,
+                 page_ids: int):
+        """
+        """
+        query = f"SELECT * FROM neuralplatform_page WHERE id IN {tuple(page_ids)};"
+        return self.select_query(query, fetchone=False)
+    
     def get_document_pages(self,
                            document_id: int) -> list:
         """
@@ -211,10 +218,9 @@ class RDSClient():
         """
         img_status = list()
         ocr_status = list()
-        for page_id in page_ids:
-            page = self.get_page(page_id)
-            img_status.append(page['imgStatus'])
-            ocr_status.append(page['ocrStatus'])
+        for page in self.get_pages(page_ids):
+            img_status.append(str(page['imgStatus']))
+            ocr_status.append(str(page['ocrStatus']))
         all_preprocessed = ( all([s in ("COMPLETED", "FAILED") for s in img_status]) and
                              all([s in ("COMPLETED", "FAILED") for s in ocr_status]) )
         return all_preprocessed, img_status, ocr_status
@@ -227,10 +233,9 @@ class RDSClient():
         img_uris = []
         ocr_uris = []
         
-        for page_id in page_ids:
-            page = self.get_page(page_id)
+        for page in self.get_pages(page_ids):
             if page['tagged'] and page['imgStatus'] == "COMPLETED" and page['ocrStatus'] == "COMPLETED":
-                query = f"SELECT classDefinition_id FROM neuralplatform_classification WHERE page_id = {page_id};"
+                query = f"SELECT classDefinition_id FROM neuralplatform_classification WHERE page_id = {page['id']};"
                 class_id = self.select_query(query, fetchone=True)['classDefinition_id']
                 classes.append(class_id)
                 img_uris.append(page['imgUri'])
